unit demomultsheets;

interface

uses 
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, Db, DBTables, XLSExportComp;

type
  TfraDemoMultiSheets = class(TFrame)
    Panel1: TPanel;
    Label1: TLabel;
    Panel2: TPanel;
    Memo1: TMemo;
    Button3: TButton;
    Label9: TLabel;
    cbOpenAfterSave: TCheckBox;
    XLSExportFile1: TXLSExportFile;
    XLSExportDataSource1: TXLSExportDataSource;
    MyBase3: TDatabase;
    dsOrds: TDataSource;
    Cust: TTable;
    dsCust: TDataSource;
    CustCustNo: TFloatField;
    CustCompany: TStringField;
    Ords: TTable;
    OrdsOrderNo: TFloatField;
    OrdsSaleDate: TDateTimeField;
    OrdsItemsTotal: TCurrencyField;
    OrdsTaxRate: TFloatField;
    OrdsFreight: TCurrencyField;
    OrdsAmountPaid: TCurrencyField;
    OrdsCustNo: TFloatField;
    ScrollBox1: TScrollBox;
    Label2: TLabel;
    Memo2: TMemo;
    Label3: TLabel;
    Image1: TImage;
    procedure Button3Click(Sender: TObject);
    procedure XLSExportDataSource1SaveTitle(FieldIndex: Integer;
      XLSCell: TCell);
    procedure XLSExportDataSource1SaveField(Field: TField; XLSCell: TCell);
    procedure XLSExportDataSource1SaveFooter(FieldIndex: Integer;
      XLSCell: TCell; var TotalCalcType: TTotalCalcType;
      var TotalRange: String);
  private
    { Private declarations }
  public
    { Public declarations }
     constructor Create(AOwner: TComponent); override;
  end;

implementation
{$R *.DFM}

uses XLSFile, XLSFormat, Main;

constructor TfraDemoMultiSheets.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  MyBase3.AliasName:= 'DBDEMOS';
end;

procedure TfraDemoMultiSheets.Button3Click(Sender: TObject);
var
  FileName: String;
  OldCursor: TCursor;
begin
  FileName:= GetNextDemoFileName;
  OldCursor:= Screen.Cursor;
  Screen.Cursor:= crHourGlass;

  try
    XLSExportFile1.Workbook.Clear;
    Cust.Open;
    Ords.Open;
    while not Cust.Eof do
    begin
      if Ords.RecordCount > 0 then
      begin
        { export DataSource to sheet named CustCompany.Value
          starting at row 3, column 0 (indexes are 0-based) }
        XLSExportDataSource1.ExportDataSheetName(CustCompany.Value, 3, 0);

        with XLSExportFile1.Workbook.SheetByName(CustCompany.Value) do
        begin
          { Set cell value }
          Cells[0, 0].Value:= 'Customer No: ' + FormatFloat('0000',CustCustNo.Value);
          Cells[1, 0].Value:= 'Customer: ' + CustCompany.Value;
          { Set cell font and color }
          Cells[1, 0].FontBold:= True;
          Cells[1, 0].FontColorIndex:= xlColorDarkBlue;
        end;
      end;

      Cust.Next;
    end;

    { save workbook data to file }
    XLSExportFile1.SaveToFile(FileName);
  finally
    Ords.Close;
    Cust.Close;
    MyBase3.Connected:= False;
    Screen.Cursor:= OldCursor;
  end;

  if cbOpenAfterSave.Checked then
    OpenFile(FileName)
  else
    Application.MessageBox(
      PChar('Result saved to ' + FileName), 'File saved', MB_OK);
end;

procedure TfraDemoMultiSheets.XLSExportDataSource1SaveTitle(
  FieldIndex: Integer; XLSCell: TCell);
begin
  { Title row export event:
    here you can customise DataSource title export }

  { Set font color for title cells }
  XLSCell.FontColorIndex:= xlColorWhite;
  { Set fill pattern and color for title cells }
  XLSCell.FillPatternBGColorIndex:= xlColorDarkBlue;
  XLSCell.FillPattern:= xlPatternSolid;
end;

procedure TfraDemoMultiSheets.XLSExportDataSource1SaveField(Field: TField;
  XLSCell: TCell);
begin
  { Cell export event:
    here you can customise default exporting options.
    Field is DataSource field, XLSCell is worksheet cell }

  { Set blue font color for ItemTotals field }
  if Field.FieldName = 'ItemsTotal' then
  begin
    XLSCell.FontColorIndex:= xlColorBlue;
  end;
end;

procedure TfraDemoMultiSheets.XLSExportDataSource1SaveFooter(
  FieldIndex: Integer; XLSCell: TCell; var TotalCalcType: TTotalCalcType;
  var TotalRange: String);
begin
  { Footer row export event:
    here you can add totals after exporting DataSource fields }

  case FieldIndex of
    0: begin
         { Place 'Totals' string to the footer for field 0}
         TotalCalcType:= tcUserDef;
         XLSCell.Value:= 'Totals';
       end;
    2: begin
         { Place sum total to the footer for fields 2, 5}
         TotalCalcType:= tcSum;
       end;
  end;
  { set bold style for all totals }
  XLSCell.FontBold:= True;
end;

end.
